@@ -135,3 +135,14 @@ emfit <- function(mim,arg="R", submitData=TRUE, emconv=0.0001, emmax=1000,plot=F
 }
 
 
+
+.initLatent <- function(set, data, info=FALSE){
+    s <- .namesToLetters(set, data)
+    if (info==TRUE)
+      cat("Initializing latent variables:", paste(set, collapse=' '), "\n")
+    s2<- paste("calc", s, "=", s, "+ln(0);")
+    mim.cmd(s2)
+}
+
+
+.dataMIM <- function(mim) mim$data
