@@ -21,16 +21,19 @@ require(RDCOMClient)
   cat("NOTICE:\n")
   cat("o mimR is available on Windows platforms only \n")
   cat("o The current version of mimR requires \n")
-  cat("  - R version 1.9.1 or later\n")
+  cat("  - R version 2.0.1 or later\n")
   cat("  - that MIM version 3.2 or later is installed on the computer\n")
   cat("    MIM can be downloaded from http://www.hypergraph.dk.\n")
   cat("  - that the R package RDCOMClient package is installed.\n")
-  cat("    The RDCOMClient package can be downloaded from http://www.omegahat.org/RDCOMClient/\n")
+  cat("    The RDCOMClient package can be downloaded from \n")
+  cat("    http://www.omegahat.org/download/R/packages/Windows/R-2.0.0/\n")
   cat("\n  For more information type ?mimR\n")
   cat("-------------------------------------------------------------\n")
   return(invisible(0))
 }
 
+
+
 .Last.lib <- function(lib) {
   cat("Thank you for using mimR\n")
   return(invisible(0))
